﻿local AceAddon = LibStub('AceAddon-3.0')
local AceDB = LibStub('AceDB-3.0')
local AceDBOptions = LibStub('AceDBOptions-3.0')
local AceConfig = LibStub('AceConfig-3.0')
local AceConfigDialog = LibStub('AceConfigDialog-3.0')

local LDB = LibStub("LibDataBroker-1.1")
local LDBI = LibStub("LibDBIcon-1.0")

local ADDON_NAME = 'ToggleMyName'
local ADDON_DB = 'ToggleMyNameDB'

local Addon = AceAddon:NewAddon(ADDON_NAME)

--------------------------------------------------------------------------
-- data broker button
local dataobj = LDB:NewDataObject(ADDON_NAME, {
	type = "data source",
	text = ADDON_NAME,
	icon = "Interface\\Icons\\ABILITY_SEAL",
	OnClick = function(clickedframe,button)
		if button=="LeftButton" then Addon:Toggle("UnitNameOwn") end
--[[
		if button=="RightButton" then Addon:ShowConfig() end
]]--
	end,
	OnTooltipShow = function(tt)
		ldbTip = CreateFrame("GameTooltip", "Broker_Tip") 
		tt:AddLine(ADDON_NAME)
		tt:AddLine("|cffffff00Click|r to toggle your character name")
	end,
})

function Addon:Toggle(var)
	SetCVar(var, GetCVar(var) == "1" and 0 or 1)
end

--------------------------------------------------------------------------
function Addon:OnInitialize()
	local defaults = {
		profile = {
			minimap = {
				show = true,
			},
		},
	}
	self.db = AceDB:New(ADDON_DB, defaults, true)
	profiles = AceDBOptions:GetOptionsTable(self.db)

	self.db.RegisterCallback(self, "OnProfileChanged", "OnProfileUpdate")
	self.db.RegisterCallback(self, "OnProfileCopied", "OnProfileUpdate")
	self.db.RegisterCallback(self, "OnProfileReset", "OnProfileUpdate")

	LDBI:Register(ADDON_NAME, dataobj, self.db.profile.minimap)

	local options = {
		type = 'group',
		name = ADDON_NAME,
		args = {
			var = {
				order = 0,
				name = ' ',
				type = 'description',
			},
			icon = {
				order = 1,
				name = 'Show Minimap Button',
				desc = 'Toggles the display of the minimap button',
				type = 'toggle',
				get = function()
					return self.db.profile.minimap.show
				end,
				set = function(k,v)
					self.db.profile.minimap.show = v
					if self.db.profile.minimap.show then
						LDBI:Show(ADDON_NAME)
					else
						LDBI:Hide(ADDON_NAME)
					end
				end,
				width = "full",
			},
		},
	}
	AceConfig:RegisterOptionsTable(ADDON_NAME, options)
	AceConfigDialog:AddToBlizOptions(ADDON_NAME)
end

function Addon:OnProfileUpdate()
	db = self.db.profile
	print ('onprofileupdate')
end
